@@ -32,3 +32,25 @@
 #     })
 #
 # }
+
+.onAttach <- function(...) {
+    attached <- tidyquant_attach()
+    if (!is_loading_for_tests()) {
+        inform_startup(tidyquant_attach_message(attached))
+    }
+
+    if (!is_attached("conflicted") && !is_loading_for_tests()) {
+        conflicts <- tidyquant_conflicts()
+        inform_startup(tidyquant_conflict_message(conflicts))
+    }
+}
+
+is_attached <- function(x) {
+    paste0("package:", x) %in% search()
+}
+
+is_loading_for_tests <- function() {
+    !interactive() && identical(Sys.getenv("DEVTOOLS_LOAD"), "tidyquant")
+}
+
+
